package net.niuxiaoer.device_identity

import android.content.Context
import android.net.wifi.WifiManager
import android.util.Log
import java.net.NetworkInterface

fun intToIp(i: Int): String {
    return try {
        (i and 0xFF).toString() + "." +
                (i shr 8 and 0xFF) + "." +
                (i shr 16 and 0xFF) + "." +
                (i shr 24 and 0xFF)
    } catch (e: java.lang.Exception) {
        e.printStackTrace()
        ""
    }

}

fun fetchIPAddress(context: Context, isUseIpV4: Boolean): String {
    val wifiManager = context.applicationContext.getSystemService(Context.WIFI_SERVICE) as WifiManager
    if (!wifiManager.isWifiEnabled) {
        try {
            val en = NetworkInterface.getNetworkInterfaces()
            while (en.hasMoreElements()) {
                val intf = en.nextElement()
                val enumIpAddr = intf.inetAddresses
                while (enumIpAddr.hasMoreElements()) {
                    val inetAddress = enumIpAddr.nextElement()
                    if (!inetAddress.isLoopbackAddress) {
                        val sAddr = inetAddress.hostAddress
                        //boolean isIPv4 = InetAddressUtils.isIPv4Address(sAddr);
                        val isIPv4 = sAddr.indexOf(':') < 0
                        if (isUseIpV4) {
                            if (isIPv4) return sAddr
                        } else {
                            if (!isIPv4) {
                                val delim = sAddr.indexOf('%') // drop ip6 zone suffix
                                return if (delim < 0) sAddr.toUpperCase() else sAddr.substring(0,
                                    delim).toUpperCase()
                            }
                        }
                    }
                }
            }
        } catch (e: java.lang.Exception) {
            Log.w("DRMID", "fetchIPAddress, failed。$e")
        }
    } else {
        val wifiInfo = wifiManager.connectionInfo
        val ipAddress = wifiInfo.ipAddress
        return intToIp(ipAddress)
    }
    return ""
}
