package net.niuxiaoer.device_identity

import android.app.Application
import android.content.Context
import android.media.MediaDrm
import android.net.wifi.WifiManager
import android.os.Build
import android.telephony.TelephonyManager
import android.util.Log
import com.github.gzuliyujiang.oaid.DeviceID
import com.github.gzuliyujiang.oaid.DeviceIdentifier
import java.util.*

class DeviceIdentityUtil(private val context: Context) {

    // 在`Application#onCreate`里初始化，注意APP合规性，若最终用户未同意隐私政策则不要调用
    fun register() {
        DeviceIdentifier.register(context as? Application)
    }

    // 获取安卓ID，可能为空
    fun getAndroidID(): String {
        return DeviceIdentifier.getAndroidID(context)
    }

    // 获取IMEI，只支持Android 10之前的系统，需要READ_PHONE_STATE权限，可能为空
    fun getIMEI(): String {
        val imei = DeviceIdentifier.getIMEI(context)

        Log.w("DRMID", "imei 1: $imei")

        return try {
            val tm = context.getSystemService(Context.TELEPHONY_SERVICE) as TelephonyManager
            Log.w("DRMID", "imei 2: ${tm.imei}")
            tm.imei ?: ""
        } catch (e: java.lang.Exception) {
            Log.w("DRMID", "fetchImei, failed。$e")
            ""
        }
    }

    // 获取OAID/AAID，同步调用
    fun getOAID(): String {
        if (DeviceID.supportedOAID(context)) {
            return DeviceIdentifier.getOAID(context)
        }

        return ""
    }

    fun getDRMID(): String {
        return  DeviceIdentifier.getWidevineID()
//        val WIDEVINE_UUID = UUID(-0x121074568629b532L,-0x5c37d8232ae2de13L)
//
//        val ddd = DeviceIdentifier.getWidevineID()
//        Log.i("DRMID", "getWidevineID: $ddd")
//
//        return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
//            val drumIdByteArray = MediaDrm(WIDEVINE_UUID)
//                .getPropertyByteArray(MediaDrm.PROPERTY_DEVICE_UNIQUE_ID)
//            val drumID= android.util.Base64.encodeToString(drumIdByteArray,android.util.Base64.DEFAULT)
//            Log.i("DRMID", "drumID: $drumID")
//            drumID
//        } else {
//            ""
//        }
    }

    // 获取UA
    fun getUA(): String {
        return System.getProperty("http.agent")
    }

    fun getIp(): String {
        return fetchIPAddress(context, true)
    }

    fun getMac(): String {
        return  getAddressMAC(context)
    }

    fun getModel(): String {
        return  Build.MODEL
    }

    fun getProduct(): String {
        return  Build.PRODUCT
    }

    fun getBssid() : String {
            return try {
                val wifiManager = context.applicationContext.getSystemService(Context.WIFI_SERVICE) as WifiManager
                wifiManager.connectionInfo.bssid ?: ""
            } catch (e: Exception) {
                Log.w("DRMID", "fetchWifiBSSID, failed。$e")
                ""
            }
    }

}